==> nextcloud-28.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/circles/l10n/it.js <==
OC.L10N.register(
    "circles",
    {
    "Circles" : "Cerchie",
    "Circles' files" : "File delle cerchie",
    "Select circles to filter by" : "Seleziona le cerchie per filtrare",
    "No circles found" : "Nessuna cerchia trovata",
    "Please select circles to filter by" : "Seleziona le cerchie per filtrare",
    "No files found for the selected circles" : "Nessun file trovato per le cerchie selezionate",
    "You created the circle {circle}" : "Hai creato la cerchia {circle}",
    "{author} created the circle {circle}" : "{author} ha creato la cerchia {circle}",
    "You deleted {circle}" : "Hai eliminato {circle}",
    "{author} deleted {circle}" : "{author} ha eliminato {circle}",
    "You linked {group} to {circle}" : "Hai collegato {group} a {circle}",
    "{group} has been linked to {circle} by {author}" : "{group} è stato collegato a {circle} da {author}",
    "You unlinked {group} from {circle}" : "Hai scollegato {group} da {circle}",
    "{group} has been unlinked from {circle} by {author}" : "{group} è stato scollegato da {circle} da {author}",
    "You changed the level of the linked group {group} in {circle} to %1$s" : "Hai modificato il livello del gruppo collegato {group} in {circle} a %1$s",
    "{author} changed the level of the linked group {group} in {circle} to %1$s" : "{author} ha modificato il tuo livello del gruppo collegato {group} in {circle} a %1$s",
    "You sent a request to link {circle} with {remote}" : "Hai inviato una richiesta di collegare {circle} a {remote}",
    "{author} sent a request to link {circle} with {remote}" : "{author} ha inviato una richiesta di collegare {circle} a {remote}",
    "{remote} requested a link with {circle}" : "{remote} ha richiesto un collegamento con {circle}",
    "The request to link {circle} with {remote} has been rejected" : "La richiesta di collegare {circle} a {remote} è stata rifiutata",
    "The request to link {remote} with {circle} has been canceled remotely" : "La richiesta di collegare {remote} a {circle} è stata annullata da remoto",
    "The request to link {circle} with {remote} has been accepted" : "La richiesta di collegare {circle} a {remote} è stata accettata",
    "You dismissed the request to link {remote} with {circle}" : "Hai scartato la richiesta di collegare {remote} a {circle}",
    "{author} dismissed the request to link {remote} with {circle}" : "{author} ha scartato la richiesta di collegare {remote} a {circle}",
    "You canceled the request to link {circle} with {remote}" : "Hai annullato la richiesta di collegare {circle} a {remote}",
    "{author} canceled the request to link {circle} with {remote}" : "{author} ha annullato la richiesta di collegare {circle} a {remote}",
    "You accepted the request to link {remote} with {circle}" : "Hai accettato la richiesta di collegare {remote} a {circle}",
    "{author} accepted the request to link {remote} with {circle}" : "{author} ha accettato la richiesta di collegare {remote} a {circle}",
    "A link between {circle} and {remote} is now up and running" : "Un collegamento tra {circle} e {remote} è ora attivo e funzionante",
    "The link between {circle} and {remote} has been shutdown remotely" : "Il collegamento tra {circle} e {remote} è stato interrotto da remoto",
    "You closed the link between {circle} and {remote}" : "Hai chiuso il collegamento tra {circle} e {remote}",
    "{author} closed the link between {circle} and {remote}" : "{author} ha chiuso il collegamento tra {circle} e {remote}",
    "You joined {circle}" : "Sei entrato a far parte di {circle}",
    "{member} joined {circle}" : "{member} si è unito a {circle}",
    "You accepted the invitation to join {circle}" : "Hai accettato l'invito per unirti {circle}",
    "{member} accepted the invitation to join {circle}" : "{member} ha accettato l'invito per unirsi a {circle}",
    "You added {member} as member to {circle}" : "Hai aggiunto {member} come membro di {circle}",
    "You have been added as member to {circle} by {author}" : "Sei stato aggiunto come membro a {circle} da {author}",
    "{member} has been added as member to {circle} by {author}" : "{member} è stato aggiunto come membro a {circle} da {author}",
    "You added {external} to {circle}" : "Hai aggiunto {external} a {circle}",
    "{external} has been added to {circle} by {author}" : "{external} è stato aggiunto a {circle} da {author}",
    "You accepted {member}'s request to join {circle}" : "Hai accettato la richiesta di {member} per unirti a {circle}",
    "Your request to join {circle} has been accepted by {author}" : "La tua richiesta di unirti a {circle} è stata accettata da {author}",
    "{member}'s request to join {circle} has been accepted by {author}" : "La richiesta di {member} di unirsi a {circle} è stata accettata da {author}",
    "You left {circle}" : "Hai abbandonato {circle}",
    "{member} left {circle}" : "{member} ha abbandonato {circle}",
    "You declined the invitation to join {circle}" : "Hai rifiutato l'invito per unirti a {circle}",
    "{member} declined an invitation to join {circle}" : "{member} ha rifiutato un invito per unirsi a {circle}",
    "You cancelled your request to join {circle}" : "Hai annullato la tua richiesta di unirti a {circle}",
    "{member} cancelled his request to join {circle}" : "{member} ha annullato la sua richiesta di unirsi a {circle}",
    "You removed {member} from {circle}" : "Hai rimosso {member} da {circle}",
    "You have been removed from {circle} by {author}" : "Sei stato rimosso da {circle} da {author}",
    "{member} has been removed from {circle} by {author}" : "{member} è stato rimosso da {circle} da {author}",
    "You removed {external} from {circle}" : "Hai rimosso {external} da {circle}",
    "{external} has been removed from {circle} by {author}" : "{external} è stato rimosso da {circle} da {author}",
    "You cancelled {member}'s invitation to join {circle}" : "Hai annullato l'invito di {member} per unirti a {circle}",
    "Your invitation to join {circle} has been cancelled by {author}" : "La tua richiesta di unirti a {circle} è stata annullata da {author}",
    "{author} cancelled {member}'s invitation to join {circle}" : "{author} ha annullato l'invito di {member} per unirsi a {circle}",
    "You dismissed {member}'s request to join {circle}" : "Hai scartato la richiesta di {member} per unirsi a {circle}",
    "Your request to join {circle} has been dismissed by {author}" : "La tua richiesta di unirti a {circle} è stata scartata da {author}",
    "{member}'s request to join {circle} has been dismissed by {author}" : "La richiesta di {member} di unirsi a {circle} è stata scartata da {author}",
    "You invited {member} to join {circle}" : "Hai invitato {member} a unirsi a {circle}",
    "You have been invited to join {circle} by {author}" : "Sei stato invitato a unirti a {circle} da {author}",
    "{member} has been invited to join {circle} by {author}" : "{member} è stato invitato a unirsi a {circle} da {author}",
    "You changed {member}'s level in {circle} to %1$s" : "Hai modificato il livello di {member} in {circle} a %1$s",
    "{author} changed your level in {circle} to %1$s" : "{author} ha modificato il tuo livello in {circle} a %1$s",
    "{author} changed {member}'s level in {circle} to %1$s" : "{author} ha modificato il livello di {member} in {circle} a %1$s",
    "You sent a request to join {circle}" : "Hai inviato una richiesta di unirti a {circle}",
    "{member} sent a request to join {circle}" : "{member} ha inviato una richiesta di unirsi a {circle}",
    "You are the new owner of {circle}" : "Sei il nuovo proprietario di {circle}",
    "{member} is the new owner of {circle}" : "{member} è il nuovo proprietario di {circle}",
    "On events happening in a <strong>Circle</strong> of which you are a member" : "Per gli eventi che si verificano in una <strong>cerchia</strong> di cui sei membro",
    "Any important event in a <strong>Circle</strong> you are moderating" : "Qualsiasi evento importante in una <strong>cerchia</strong> di cui sei moderatore",
    "On global events happening in any <strong>Circle</strong>" : "Per eventi globali che si verificano in qualsiasi <strong>cerchia</strong>",
    "Shared to Circles" : "Condivisi con cerchie",
    "Single" : "Singola",
    "Personal" : "Personale",
    "System" : "Sistema",
    "Visible" : "Visibile",
    "Open" : "Apri",
    "Invite" : "Invita",
    "Join Request" : "Richiesta di unirsi",
    "Friends" : "Amici",
    "Password Protected" : "Protetta da password",
    "No Owner" : "Nessun proprietario",
    "Hidden" : "Nascosta",
    "Backend" : "Motore",
    "Local" : "Locale",
    "Root" : "Radice",
    "Circle Invite" : "Invito della cerchia",
    "Federated" : "Federata",
    "Mount point" : "Punto di mount",
    "Nextcloud Account" : "Account Nextcloud",
    "Nextcloud Group" : "Gruppo Nextcloud",
    "Email Address" : "Indirizzo email",
    "Contact" : "Contatto",
    "Circle" : "Cerchia",
    "Nextcloud App" : "Applicazione Nextcloud",
    "Member" : "Membro",
    "Moderator" : "Moderatore",
    "Admin" : "Amministratore",
    "Owner" : "Proprietario",
    "%s shared »%s« with you." : "%s ha condiviso «%s» con te.",
    "%s shared »%s« with \"%s\"." : "%s ha condiviso »%s« con \"%s\".",
    "%s on %s" : "%s su %s",
    "%1$s shared »%2$s« with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s ha condiviso »%2$s« con te.\nDovresti aver già ricevuto un'email separata con un collegamento per accedervi.\n",
    "%1$s shared »%2$s« with you. You should have already received a separate email with a link to access it." : "%1$s ha condiviso »%2$s« con te. Dovresti aver già ricevuto un'email separata con un collegamento per accedervi.",
    "Password to access »%1$s« shared to you by %2$s" : "Password per accedere a «%1$s» condivisa con te da %2$s",
    "Password to access »%s«" : "Password per accedere a «%s»",
    "It is protected with the following password:" : "È protetta con la password seguente:",
    "%1$s via %2$s" : "%1$s tramite %2$s",
    "Click the button below to open it." : "Fai clic sul pulsante sotto per aprirlo.",
    "Open »%s«" : "Apri «%s»",
    "%1$s shared multiple files with you.\nYou should have already received a separate email with a link to access them.\n" : "%1$s ha condiviso diversi file con te.\nDovresti aver già ricevuto un'email separata con un collegamento per accedervi.\n",
    "%1$s shared multiple files with you. You should have already received a separate email with a link to access them." : "%1$s ha condiviso diversi file con te. Dovresti aver già ricevuto un'email separata con un collegamento per accedervi.",
    "Password to access files shared to you by %1$s" : "Password per accedere ai file condivisi con te da %1$s",
    "Password to access files" : "Password per accedere ai file",
    "%s shared multiple files with \"%s\"." : "%s ha condiviso più file con \"%s\".",
    "%s shared multiple files with you." : "%s ha condiviso più file con te.",
    "Boot up" : "Avvia",
    "Nextcloud Initialization" : "Inizializzazione Nextcloud",
    "Circles App Initialization" : "Inizializzazione app Cerchie",
    "Fresh installation status" : "Stato nuova installazione",
    "Building Local Database" : "Costruzione database locale",
    "Testing Basic Circle Creation" : "Test creazione cerchia di base",
    "Adding local users and moderators" : "Aggiunta di utenti locali e moderatori",
    "Circle not found" : "Cerchia non trovata",
    "Circle not found " : "Cerchia non trovata",
    "This member does not exist" : "Questo membro non esiste",
    "This account is already a member of the circle" : "Questo account è già un membro della cerchia",
    "Federated link not found" : "Collegamento federato non trovato",
    "This feature is not available for personal circles" : "Questa funzionalità non è disponibile nelle cerchie personali",
    "The circle is not federated" : "La cerchia non è federata",
    "You cannot join this circle" : "Non puoi unirti a questa cerchia",
    "This member is not a moderator" : "Questo membro non è un moderatore",
    "Insufficient privileges" : "Permessi insufficienti",
    "This member is the owner of the circle" : "Questo membro non è il proprietario della cerchia",
    "Level cannot be changed for this type of member" : "Il livello non può essere modificato per questo tipo di membro",
    "You are already a member of this circle" : "Sei già un membro di questa cerchia",
    "You have been blocked from this circle" : "Sei stato bloccato da questa cerchia",
    "The account is already a member of this circle" : "L'account è già membro di questa cerchia",
    "The account has already been invited into this circle" : "L'account è già stato invitato in questa cerchia",
    "%s (Circle owned by %s)" : "%s (Cerchi di proprietà di %s)",
    "You are now a member of the Circle \"%2$s\"" : "Ora sei membro della cerchia \"%2$s\"",
    "You have been invited by %1$s into the Circle \"%2$s\"" : "Sei stato invitato da %1$s nella cerchia \"%2$s\"",
    "%1$s sent a request to be a member of the Circle \"%2$s\"" : "%1$s ha inviato una richiesta per essere membro della cerchia \"%2$s\"",
    "Accept" : "Accetta",
    "Refuse" : "Rifiuta",
    "Leave the circle" : "Abbandona la cerchia",
    "%s" : "%s",
    "Personal Circle" : "Cerchia personale",
    "%s owned by %s" : "%s posseduto da %s",
    "You need a specify a type of circle" : "Devi specificare un tipo di cerchia",
    "A circle with that name exists" : "Una cerchia con quel nome esiste già",
    "This member is not the owner of the circle" : "Questo membro non è il proprietario della cerchia",
    "This member is not an admin of the circle" : "Questo membro non è amministratore della cerchia",
    "Group contains too many members" : "Il gruppo contiene troppi membri",
    "This group does not exist" : "Questo gruppo non esiste",
    "This group is already linked to the circle" : "Il gruppo è già collegato alla cerchia",
    "You cannot edit level in a personal circle" : "Non puoi modificare il livello in una cerchia personale",
    "Group cannot be set as owner of a circle" : "Un gruppo non può essere impostato come proprietario di una cerchia",
    "now" : "adesso",
    "This account does not exist" : "Questo account non esiste",
    "Email format is not valid" : "Il formato dell'indirizzo di posta non è valido",
    "This contact is not available" : "Questa contatto non è disponibile",
    "You have no permission to create a new circle" : "Non ti è consentito creare un nuovo circolo",
    "%s shared a file with \"%s\"." : "%s ha condiviso un file con \"%s\".",
    "%s shared a file with you." : "%s ha condiviso un file con te.",
    "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s ha condiviso qualcosa con te.\nDovresti aver già ricevuto un'email separata con un collegamento per accedervi.\n",
    "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s ha condiviso qualcosa con te. Dovresti aver già ricevuto un'email separata con un collegamento per accedervi.",
    "Password to access content shared with you by %1$s" : "Password per accedere ai contenuti condivisi con te da %1$s",
    "Password to access content" : "Password per accedere ai contenuti",
    "This item is already shared with this circle" : "Questo elemento è già condiviso con questa cerchia",
    "Bring cloud-users closer together." : "Avvicina gli utenti del cloud",
    "Circles allows people to create their own groups of people/colleagues/friends.\nThose groups of people (or \"circles\") can then be used by any other app for sharing purpose." : "Le cerchie consentono alle persone di creare i propri gruppi di persone/colleghi/amici.\nQuesti gruppi di persone (o \"cerchie\") possono quindi essere utilizzati da qualsiasi altra app per scopi di condivisione.",
    "No files in here" : "Nessun file qui",
    "No entries found in this folder" : "Nessuna voce trovata in questa cartella",
    "Name" : "Nome",
    "Size" : "Dimensione",
    "Modified" : "Modificato",
    "Initialisation Nextcloud" : "Inizializzazione di Nextcloud",
    "Initialisation Circles App" : "Inizializzazione applicazione Cerchie"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> nextcloud-31.0.8-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/circles/l10n/it.js <==
OC.L10N.register(
    "circles",
    {
    "Teams" : "Team",
    "You created the team {circle}" : "Hai creato il team {circle}",
    "{author} created the team {circle}" : "{author} ha creato il team {circle}",
    "You deleted {circle}" : "Hai eliminato {circle}",
    "{author} deleted {circle}" : "{author} ha eliminato {circle}",
    "You made {member} join {circle}" : "Hai fatto {member} entrare in {circle}",
    "{author} made {member} join {circle}" : "{author} ha fatto {member} entrare in {circle}",
    "You added team {member} as member to {circle}" : "Hai aggiunto team {member} come membro di {circle}",
    "{author} added team {member} as member to {circle}" : "{author} ha aggiunto team {member} come membro di {circle}",
    "You made {member} leave {circle}" : "Hai fatto {member} uscire da {circle}",
    "{author} made {member} leave {circle}" : "{author} ha fatto {member} uscire da {circle}",
    "You removed {member} from {circle}" : "Hai rimosso {member} da {circle}",
    "{author} removed {member} from {circle}" : "{author} ha rimosso {member} da {circle}",
    "You joined {circle}" : "Sei entrato a far parte di {circle}",
    "{member} joined {circle}" : "{member} si è unito a {circle}",
    "You accepted the invitation to join {circle}" : "Hai accettato l'invito per unirti {circle}",
    "{member} accepted the invitation to join {circle}" : "{member} ha accettato l'invito per unirsi a {circle}",
    "You added {member} as member to {circle}" : "Hai aggiunto {member} come membro di {circle}",
    "You have been added as member to {circle} by {author}" : "Sei stato aggiunto come membro a {circle} da {author}",
    "{member} has been added as member to {circle} by {author}" : "{member} è stato aggiunto come membro a {circle} da {author}",
    "You added {external} to {circle}" : "Hai aggiunto {external} a {circle}",
    "{external} has been added to {circle} by {author}" : "{external} è stato aggiunto a {circle} da {author}",
    "You accepted {member}'s request to join {circle}" : "Hai accettato la richiesta di {member} per unirti a {circle}",
    "Your request to join {circle} has been accepted by {author}" : "La tua richiesta di unirti a {circle} è stata accettata da {author}",
    "{member}'s request to join {circle} has been accepted by {author}" : "La richiesta di {member} di unirsi a {circle} è stata accettata da {author}",
    "You left {circle}" : "Hai abbandonato {circle}",
    "{member} left {circle}" : "{member} ha abbandonato {circle}",
    "You declined the invitation to join {circle}" : "Hai rifiutato l'invito per unirti a {circle}",
    "{member} declined an invitation to join {circle}" : "{member} ha rifiutato un invito per unirsi a {circle}",
    "You cancelled your request to join {circle}" : "Hai annullato la tua richiesta di unirti a {circle}",
    "{member} cancelled a request to join {circle}" : "{member} ha cancellato la richiesta di ingresso a {circle}",
    "You have been removed from {circle} by {author}" : "Sei stato rimosso da {circle} da {author}",
    "{member} has been removed from {circle} by {author}" : "{member} è stato rimosso da {circle} da {author}",
    "You removed {external} from {circle}" : "Hai rimosso {external} da {circle}",
    "{external} has been removed from {circle} by {author}" : "{external} è stato rimosso da {circle} da {author}",
    "You cancelled {member}'s invitation to join {circle}" : "Hai annullato l'invito di {member} per unirti a {circle}",
    "Your invitation to join {circle} has been cancelled by {author}" : "La tua richiesta di unirti a {circle} è stata annullata da {author}",
    "{author} cancelled {member}'s invitation to join {circle}" : "{author} ha annullato l'invito di {member} per unirsi a {circle}",
    "You dismissed {member}'s request to join {circle}" : "Hai scartato la richiesta di {member} per unirsi a {circle}",
    "Your request to join {circle} has been dismissed by {author}" : "La tua richiesta di unirti a {circle} è stata scartata da {author}",
    "{member}'s request to join {circle} has been dismissed by {author}" : "La richiesta di {member} di unirsi a {circle} è stata scartata da {author}",
    "You invited {member} to join {circle}" : "Hai invitato {member} a unirsi a {circle}",
    "You have been invited to join {circle} by {author}" : "Sei stato invitato a unirti a {circle} da {author}",
    "{member} has been invited to join {circle} by {author}" : "{member} è stato invitato a unirsi a {circle} da {author}",
    "You changed {member}'s level in {circle} to %1$s" : "Hai modificato il livello di {member} in {circle} a %1$s",
    "{author} changed your level in {circle} to %1$s" : "{author} ha modificato il tuo livello in {circle} a %1$s",
    "{author} changed {member}'s level in {circle} to %1$s" : "{author} ha modificato il livello di {member} in {circle} a %1$s",
    "You sent a request to join {circle}" : "Hai inviato una richiesta di unirti a {circle}",
    "{member} sent a request to join {circle}" : "{member} ha inviato una richiesta di unirsi a {circle}",
    "You are the new owner of {circle}" : "Sei il nuovo proprietario di {circle}",
    "{member} is the new owner of {circle}" : "{member} è il nuovo proprietario di {circle}",
    "On events happening in a <strong>team</strong> of which you are a member" : "Sugli eventi che accadono in un <strong>team</strong> di cui sei membro",
    "Any important event in a <strong>team</strong> you are moderating" : "Qualsiasi evento importante in un <strong>team</strong> che stai moderando",
    "On global events happening in any <strong>team</strong>" : "Sugli eventi globali che accadono in qualsiasi <strong>team</strong>",
    "Single" : "Singola",
    "Personal" : "Personale",
    "System" : "Sistema",
    "Visible" : "Visibile",
    "Open" : "Apri",
    "Invite" : "Invita",
    "Join request" : "Richiesta di adesione",
    "Friends" : "Amici",
    "Password protected" : "Protetto da password",
    "No Owner" : "Nessun proprietario",
    "Hidden" : "Nascosta",
    "Backend" : "Motore",
    "Local" : "Locale",
    "Root" : "Radice",
    "Team invite" : "Invito dal team",
    "Federated" : "Federata",
    "Mount point" : "Punto di mount",
    "Nextcloud Account" : "Account Nextcloud",
    "Nextcloud Group" : "Gruppo Nextcloud",
    "Email address" : "Indirizzo email",
    "Contact" : "Contatto",
    "Circle" : "Cerchia",
    "Nextcloud App" : "Applicazione Nextcloud",
    "Member" : "Membro",
    "Moderator" : "Moderatore",
    "Admin" : "Amministratore",
    "Owner" : "Proprietario",
    "%s shared »%s« with you." : "%s ha condiviso «%s» con te.",
    "%s shared »%s« with \"%s\"." : "%s ha condiviso »%s« con \"%s\".",
    "%s on %s" : "%s su %s",
    "%1$s shared »%2$s« with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s ha condiviso »%2$s« con te.\nDovresti aver già ricevuto un'email separata con un collegamento per accedervi.\n",
    "%1$s shared »%2$s« with you. You should have already received a separate email with a link to access it." : "%1$s ha condiviso »%2$s« con te. Dovresti aver già ricevuto un'email separata con un collegamento per accedervi.",
    "Password to access »%1$s« shared to you by %2$s" : "Password per accedere a «%1$s» condivisa con te da %2$s",
    "Password to access »%s«" : "Password per accedere a «%s»",
    "It is protected with the following password:" : "È protetta con la password seguente:",
    "%1$s via %2$s" : "%1$s tramite %2$s",
    "Click the button below to open it." : "Fai clic sul pulsante sotto per aprirlo.",
    "Open »%s«" : "Apri «%s»",
    "%1$s shared multiple files with you.\nYou should have already received a separate email with a link to access them.\n" : "%1$s ha condiviso diversi file con te.\nDovresti aver già ricevuto un'email separata con un collegamento per accedervi.\n",
    "%1$s shared multiple files with you. You should have already received a separate email with a link to access them." : "%1$s ha condiviso diversi file con te. Dovresti aver già ricevuto un'email separata con un collegamento per accedervi.",
    "Password to access files shared to you by %1$s" : "Password per accedere ai file condivisi con te da %1$s",
    "Password to access files" : "Password per accedere ai file",
    "%s shared multiple files with \"%s\"." : "%s ha condiviso più file con \"%s\".",
    "%s shared multiple files with you." : "%s ha condiviso più file con te.",
    "Boot up" : "Avvia",
    "Nextcloud Initialization" : "Inizializzazione Nextcloud",
    "Circles App Initialization" : "Inizializzazione app Cerchie",
    "Fresh installation status" : "Stato nuova installazione",
    "Building Local Database" : "Costruzione database locale",
    "Testing Basic Circle Creation" : "Test creazione cerchia di base",
    "Adding local users and moderators" : "Aggiunta di utenti locali e moderatori",
    "Show all teams" : "Mostra tutti i team",
    "Create a new team" : "Crea un nuovo team",
    "Files" : "File",
    "This feature is not available for personal circles" : "Questa funzionalità non è disponibile nelle cerchie personali",
    "The team is not federated" : "Il team non è federato",
    "You cannot join this team" : "Non puoi unirti a questo team",
    "This member is not a moderator" : "Questo membro non è un moderatore",
    "Insufficient privileges" : "Permessi insufficienti",
    "This member does not exist" : "Questo membro non esiste",
    "This member is the owner of the team" : "Questo membro è il proprietario del team",
    "Level cannot be changed for this type of member" : "Il livello non può essere modificato per questo tipo di membro",
    "You are already a member of this circle" : "Sei già un membro di questa cerchia",
    "You have been blocked from this circle" : "Sei stato bloccato da questa cerchia",
    "The account is already a member of this circle" : "L'account è già membro di questa cerchia",
    "The account has already been invited into this circle" : "L'account è già stato invitato in questa cerchia",
    "%s (Team owned by %s)" : "%s (Team di proprietà di %s)",
    "You are now a member of the Team \"%2$s\"" : "Ora sei un membro del Team \"%2$s\"",
    "You have been invited by %1$s into the Team \"%2$s\"" : "Sei stato invitato da %1$s dentro al Team \"%2$s\"",
    "%1$s sent a request to be a member of the Team \"%2$s\"" : "%1$s ha inviato una richiesta per diventare membro del Team \"%2$s\"",
    "Accept" : "Accetta",
    "Refuse" : "Rifiuta",
    "Leave the team" : "Lascia il team",
    "%s" : "%s",
    "Personal team" : "Team personale",
    "%s owned by %s" : "%s posseduto da %s",
    "You have no permission to create a new team" : "Non hai il permesso di creare un nuovo team",
    "%s shared a file with \"%s\"." : "%s ha condiviso un file con \"%s\".",
    "%s shared a file with you." : "%s ha condiviso un file con te.",
    "%1$s shared %2$s with %3$s" : "%1$s condiviso %2$s con %3$s",
    "%1$s shared %2$s with \"%3$s\"" : "%1$s condiviso %2$s con \"%3$s\"",
    "Open %s" : "Apri %s",
    "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s ha condiviso qualcosa con te.\nDovresti aver già ricevuto un'email separata con un collegamento per accedervi.\n",
    "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s ha condiviso qualcosa con te. Dovresti aver già ricevuto un'email separata con un collegamento per accedervi.",
    "Password to access content shared with you by %1$s" : "Password per accedere ai contenuti condivisi con te da %1$s",
    "Password to access content" : "Password per accedere ai contenuti",
    "This item is already shared with this team" : "Questo elemento è già condiviso con questo team",
    "Bring cloud-users closer together." : "Avvicina gli utenti del cloud",
    "Teams allows people to create their own groups of people/colleagues/friends.\nThose groups of people can then be used by any other app for sharing purpose." : "Teams consente alle persone di creare i propri gruppi di persone/colleghi/amici. Questi gruppi di persone possono poi essere utilizzati da qualsiasi altra app per scopi di condivisione.",
    "No files in here" : "Nessun file qui",
    "No entries found in this folder" : "Nessuna voce trovata in questa cartella",
    "Name" : "Nome",
    "Size" : "Dimensione",
    "Modified" : "Modificato",
    "Teams' files" : "File team",
    "Select team to filter by" : "Seleziona team per filtrare",
    "No teams found" : "Nessun  team trovato",
    "Please select teams to filter by" : "Seleziona i team per filtrare ",
    "No files found for the selected teams" : "Nessun file trovato per i team selezionati",
    "Shared to Circles" : "Condivisi con cerchie"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
